@@ -25,6 +25,8 @@
 #include "debug.h"
 #include <QMutexLocker>
 #include <QTimer>
+#include <QDBusServiceWatcher>
+#include <QDBusConnection>
 
 #include "card.h"
 #include "client.h"
@@ -177,6 +179,16 @@ Context::Context(QObject *parent)
     , m_mainloop(nullptr)
     , m_references(0)
 {
+    QDBusServiceWatcher *watcher = new QDBusServiceWatcher(QStringLiteral("org.pulseaudio.Server"),
+                                                           QDBusConnection::sessionBus(),
+                                                           QDBusServiceWatcher::WatchForRegistration,
+                                                           this);
+    connect(watcher, &QDBusServiceWatcher::serviceRegistered, this, [this]() {
+        if (!m_context) {
+            connectToDaemon();
+        }
+    });
+
     connectToDaemon();
 }
 
@@ -431,6 +443,9 @@ void Context::serverCallback(const pa_server_info *info)
 
 void Context::setCardProfile(quint32 index, const QString &profile)
 {
+    if (!m_context) {
+        return;
+    }
     qCDebug(PLASMAPA) << index << profile;
     if (!PAOperation(pa_context_set_card_profile_by_index(m_context,
                                                           index,
@@ -443,6 +458,9 @@ void Context::setCardProfile(quint32 index, const QString &profile)
 
 void Context::setDefaultSink(const QString &name)
 {
+    if (!m_context) {
+        return;
+    }
     const QByteArray nameData = name.toUtf8();
     if (!PAOperation(pa_context_set_default_sink(m_context,
                                                  nameData.constData(),
@@ -454,6 +472,9 @@ void Context::setDefaultSink(const QString &name)
 
 void Context::setDefaultSource(const QString &name)
 {
+    if (!m_context) {
+        return;
+    }
     const QByteArray nameData = name.toUtf8();
     if (!PAOperation(pa_context_set_default_source(m_context,
                                                  nameData.constData(),
@@ -465,6 +486,9 @@ void Context::setDefaultSource(const QString &name)
 
 void Context::streamRestoreWrite(const pa_ext_stream_restore_info *info)
 {
+    if (!m_context) {
+        return;
+    }
     if (!PAOperation(pa_ext_stream_restore_write(m_context,
                                                  PA_UPDATE_REPLACE,
                                                  info,
